Stackplot styling
-----------------

`~.Axes.stackplot` now accepts sequences for the style parameters *facecolor*,
*edgecolor*, *linestyle*, and *linewidth*, similar to how the *hatch* parameter
is already handled.
